==> daal-devel-2018.0.0.20170814-0.tar.bz2: pydaal_sources/daal/algorithms/linear_model/prediction.py <==
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_prediction9', [dirname(__file__)])
        except ImportError:
            import _prediction9
            return _prediction9
        if fp is not None:
            try:
                _mod = imp.load_module('_prediction9', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _prediction9 = swig_import_helper()
    del swig_import_helper
else:
    import _prediction9
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.linear_model
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import daal.algorithms.regression
import daal.algorithms.regression.prediction

_prediction9.defaultDense_swigconstant(_prediction9)
defaultDense = _prediction9.defaultDense

_prediction9.data_swigconstant(_prediction9)
data = _prediction9.data

_prediction9.lastNumericTableInputId_swigconstant(_prediction9)
lastNumericTableInputId = _prediction9.lastNumericTableInputId

_prediction9.model_swigconstant(_prediction9)
model = _prediction9.model

_prediction9.lastModelInputId_swigconstant(_prediction9)
lastModelInputId = _prediction9.lastModelInputId

_prediction9.prediction_swigconstant(_prediction9)
prediction = _prediction9.prediction

_prediction9.lastResultId_swigconstant(_prediction9)
lastResultId = _prediction9.lastResultId
class Input(daal.algorithms.regression.prediction.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _prediction9.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getTable(self, id):
        return _prediction9.Input_getTable(self, id)

    def getModel(self, id):
        return _prediction9.Input_getModel(self, id)

    def setTable(self, id, value):
        return _prediction9.Input_setTable(self, id, value)

    def setModel(self, id, value):
        return _prediction9.Input_setModel(self, id, value)

    def check(self, parameter, method):
        return _prediction9.Input_check(self, parameter, method)
    __swig_destroy__ = _prediction9.delete_Input
    __del__ = lambda self: None
Input_swigregister = _prediction9.Input_swigregister
Input_swigregister(Input)

class Result(daal.algorithms.regression.prediction.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr
    __swig_getmethods__["serializationTag"] = lambda x: _prediction9.Result_serializationTag
    if _newclass:
        serializationTag = staticmethod(_prediction9.Result_serializationTag)

    def getSerializationTag(self):
        return _prediction9.Result_getSerializationTag(self)

    def __init__(self, nElements=0):
        this = _prediction9.new_Result(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this

    def get(self, id):
        return _prediction9.Result_get(self, id)

    def set(self, id, value):
        return _prediction9.Result_set(self, id, value)

    def check(self, input, par, method):
        return _prediction9.Result_check(self, input, par, method)

    def allocate_Float64(self, input, par, method):
        r"""
This function is specialized for float64"""
        return _prediction9.Result_allocate_Float64(self, input, par, method)


    def allocate_Float32(self, input, par, method):
        r"""
This function is specialized for float32"""
        return _prediction9.Result_allocate_Float32(self, input, par, method)

    __swig_destroy__ = _prediction9.delete_Result
    __del__ = lambda self: None
Result_swigregister = _prediction9.Result_swigregister
Result_swigregister(Result)

def Result_serializationTag():
    return _prediction9.Result_serializationTag()
Result_serializationTag = _prediction9.Result_serializationTag

class Batch_Float64DefaultDense(daal.algorithms.regression.prediction.Batch):
    r"""
This class is an alias of Batch(fptype=float64, method=daal.algorithms.linear_model.prediction.defaultDense)
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float64DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float64DefaultDense, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getMethod(self):
        return _prediction9.Batch_Float64DefaultDense_getMethod(self)

    def getResult(self):
        return _prediction9.Batch_Float64DefaultDense_getResult(self)

    def compute(self):
        return _prediction9.Batch_Float64DefaultDense_compute(self)
    __swig_destroy__ = _prediction9.delete_Batch_Float64DefaultDense
    __del__ = lambda self: None
Batch_Float64DefaultDense_swigregister = _prediction9.Batch_Float64DefaultDense_swigregister
Batch_Float64DefaultDense_swigregister(Batch_Float64DefaultDense)

class Batch_Float32DefaultDense(daal.algorithms.regression.prediction.Batch):
    r"""
This class is an alias of Batch(fptype=float32, method=daal.algorithms.linear_model.prediction.defaultDense)
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float32DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float32DefaultDense, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getMethod(self):
        return _prediction9.Batch_Float32DefaultDense_getMethod(self)

    def getResult(self):
        return _prediction9.Batch_Float32DefaultDense_getResult(self)

    def compute(self):
        return _prediction9.Batch_Float32DefaultDense_compute(self)
    __swig_destroy__ = _prediction9.delete_Batch_Float32DefaultDense
    __del__ = lambda self: None
Batch_Float32DefaultDense_swigregister = _prediction9.Batch_Float32DefaultDense_swigregister
Batch_Float32DefaultDense_swigregister(Batch_Float32DefaultDense)

from numpy import float64, float32, intc

class Batch(object):
    r"""Factory class for different types of Batch."""
    def __new__(cls,
                *args, **kwargs):
        if 'fptype' not in kwargs or kwargs['fptype'] == float64:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float64DefaultDense(*args)
        if 'fptype' in kwargs and kwargs['fptype'] == float32:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float32DefaultDense(*args)

        raise RuntimeError("No appropriate constructor found for Batch")


# This file is compatible with both classic and new-style classes.

==> daal-devel-2020.0-166.tar.bz2: pydaal_sources/daal/algorithms/linear_model/prediction.py <==
# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_prediction11_', [dirname(__file__)])
        except ImportError:
            import _prediction11_
            return _prediction11_
        if fp is not None:
            try:
                _mod = imp.load_module('_prediction11_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _prediction11_ = swig_import_helper()
    del swig_import_helper
else:
    import _prediction11_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.linear_model
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.features
import daal.data_management.modifiers.csv
import daal.data_management.modifiers
import daal.algorithms.regression
import daal.algorithms.regression.prediction

_prediction11_.defaultDense_swigconstant(_prediction11_)
defaultDense = _prediction11_.defaultDense

_prediction11_.data_swigconstant(_prediction11_)
data = _prediction11_.data

_prediction11_.lastNumericTableInputId_swigconstant(_prediction11_)
lastNumericTableInputId = _prediction11_.lastNumericTableInputId

_prediction11_.model_swigconstant(_prediction11_)
model = _prediction11_.model

_prediction11_.lastModelInputId_swigconstant(_prediction11_)
lastModelInputId = _prediction11_.lastModelInputId

_prediction11_.prediction_swigconstant(_prediction11_)
prediction = _prediction11_.prediction

_prediction11_.lastResultId_swigconstant(_prediction11_)
lastResultId = _prediction11_.lastResultId
class Input(daal.algorithms.regression.prediction.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _prediction11_.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getTable(self, id):
        return _prediction11_.Input_getTable(self, id)

    def getModel(self, id):
        return _prediction11_.Input_getModel(self, id)

    def setTable(self, id, value):
        return _prediction11_.Input_setTable(self, id, value)

    def setModel(self, id, value):
        return _prediction11_.Input_setModel(self, id, value)

    def check(self, parameter, method):
        return _prediction11_.Input_check(self, parameter, method)
    __swig_destroy__ = _prediction11_.delete_Input
    __del__ = lambda self: None
Input_swigregister = _prediction11_.Input_swigregister
Input_swigregister(Input)

class Result(daal.algorithms.regression.prediction.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr
    __swig_getmethods__["serializationTag"] = lambda x: _prediction11_.Result_serializationTag
    if _newclass:
        serializationTag = staticmethod(_prediction11_.Result_serializationTag)

    def getSerializationTag(self):
        return _prediction11_.Result_getSerializationTag(self)

    def __init__(self, nElements=0):
        this = _prediction11_.new_Result(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this

    def get(self, id):
        return _prediction11_.Result_get(self, id)

    def set(self, id, value):
        return _prediction11_.Result_set(self, id, value)

    def check(self, input, par, method):
        return _prediction11_.Result_check(self, input, par, method)

    def allocate_Float64(self, input, par, method):
        r"""
    This function is specialized for float64"""
        return _prediction11_.Result_allocate_Float64(self, input, par, method)


    def allocate_Float32(self, input, par, method):
        r"""
    This function is specialized for float32"""
        return _prediction11_.Result_allocate_Float32(self, input, par, method)

    __swig_destroy__ = _prediction11_.delete_Result
    __del__ = lambda self: None
Result_swigregister = _prediction11_.Result_swigregister
Result_swigregister(Result)

def Result_serializationTag():
    return _prediction11_.Result_serializationTag()
Result_serializationTag = _prediction11_.Result_serializationTag

class Batch_Float64DefaultDense(daal.algorithms.regression.prediction.Batch):
    r"""
    This class is an alias of Batch()
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float64DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float64DefaultDense, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getMethod(self):
        return _prediction11_.Batch_Float64DefaultDense_getMethod(self)

    def getResult(self):
        return _prediction11_.Batch_Float64DefaultDense_getResult(self)

    def compute(self):
        return _prediction11_.Batch_Float64DefaultDense_compute(self)
    __swig_destroy__ = _prediction11_.delete_Batch_Float64DefaultDense
    __del__ = lambda self: None
Batch_Float64DefaultDense_swigregister = _prediction11_.Batch_Float64DefaultDense_swigregister
Batch_Float64DefaultDense_swigregister(Batch_Float64DefaultDense)

class Batch_Float32DefaultDense(daal.algorithms.regression.prediction.Batch):
    r"""
    This class is an alias of Batch()
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float32DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.prediction.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float32DefaultDense, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getMethod(self):
        return _prediction11_.Batch_Float32DefaultDense_getMethod(self)

    def getResult(self):
        return _prediction11_.Batch_Float32DefaultDense_getResult(self)

    def compute(self):
        return _prediction11_.Batch_Float32DefaultDense_compute(self)
    __swig_destroy__ = _prediction11_.delete_Batch_Float32DefaultDense
    __del__ = lambda self: None
Batch_Float32DefaultDense_swigregister = _prediction11_.Batch_Float32DefaultDense_swigregister
Batch_Float32DefaultDense_swigregister(Batch_Float32DefaultDense)

from numpy import float64, float32, intc

class Batch(object):
    r"""Factory class for different types of Batch."""
    def __new__(cls,
                *args, **kwargs):
        if 'fptype' not in kwargs or kwargs['fptype'] == float64:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float64DefaultDense(*args)
        if 'fptype' in kwargs and kwargs['fptype'] == float32:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float32DefaultDense(*args)

        raise RuntimeError("No appropriate constructor found for Batch")


# This file is compatible with both classic and new-style classes.
